@@ -1,4 +1,4 @@
-#       $Id: Rule.pm 1301 2003-06-22 21:50:16Z richardc $
+#       $Id: Rule.pm 1368 2003-08-03 22:06:41Z richardc $
 
 package File::Find::Rule;
 use strict;
@@ -10,7 +10,7 @@ use Carp qw/croak/;
 use File::Find (); # we're only wrapping for now
 use Cwd;           # 5.00503s File::Find goes screwy with max_depth == 0
 
-$VERSION = '0.20_02';
+$VERSION = '0.20_03';
 
 # we'd just inherit from Exporter, but I want the colon
 sub import {
@@ -524,15 +524,17 @@ sub in {
         my $maxdepth = $self->{maxdepth};
         my $mindepth = $self->{mindepth};
 
-        # XXX fixme.  this should be the split of the path less the
-        # initial path
+        # figure out the relative path and depth
+        my $relpath = $File::Find::name;
+        $relpath =~ s{^\Q$File::Find::topdir\E/?}{};
+        my $depth = scalar File::Spec->splitdir($relpath);
+        #print "name: \'$File::Find::name\' ";
+        #print "relpath: \'$relpath\' depth: $depth\n";
 
-        my $depth = scalar File::Spec->splitdir($File::Find::name);
-
-        defined $maxdepth && $depth > $maxdepth
+        defined $maxdepth && $depth >= $maxdepth
            and $File::Find::prune = 1;
 
-        defined $mindepth && $depth <= $mindepth
+        defined $mindepth && $depth < $mindepth
            and return;
 
         #print "Testing \'$_\'\n";
